@@ -1,4 +1,4 @@
-""" MIDI-like encoding method similar to ???
+"""MIDI-like encoding method similar to ???
 Music Transformer:
 
 """
@@ -15,7 +15,7 @@ from .constants import *
 
 
 class MIDILike(MIDITokenizer):
-    """ MIDI-Like encoding, used with Music Transformer or MT3
+    r"""MIDI-Like encoding, used with Music Transformer or MT3
     https://arxiv.org/abs/1808.03715
     This strategy simply convert MIDI messages into distinct tokens.
     The token types are then Note-On, Velocity, Note-Off and Time-Shift
@@ -44,7 +44,7 @@ class MIDILike(MIDITokenizer):
         super().__init__(pitch_range, beat_res, nb_velocities, additional_tokens, sos_eos_tokens, mask, params)
 
     def track_to_tokens(self, track: Instrument) -> List[int]:
-        """ Converts a track (miditoolkit.Instrument object) into a sequence of tokens
+        r"""Converts a track (miditoolkit.Instrument object) into a sequence of tokens
         (can probably be achieved faster with Mido objects)
 
         :param track: MIDI track to convert
@@ -133,7 +133,7 @@ class MIDILike(MIDITokenizer):
     def tokens_to_track(self, tokens: List[int], time_division: Optional[int] = TIME_DIVISION,
                         program: Optional[Tuple[int, bool]] = (0, False), default_duration: int = None) \
             -> Tuple[Instrument, List[TempoChange]]:
-        """ Converts a sequence of tokens into a track object
+        r"""Converts a sequence of tokens into a track object
 
         :param tokens: sequence of tokens to convert
         :param time_division: MIDI time division / resolution, in ticks/beat (of the MIDI to create)
@@ -198,9 +198,9 @@ class MIDILike(MIDITokenizer):
         return instrument, tempo_changes
 
     def _create_vocabulary(self, sos_eos_tokens: bool = None) -> Vocabulary:
-        """ Creates the Vocabulary object of the tokenizer.
+        r"""Creates the Vocabulary object of the tokenizer.
         See the docstring of the Vocabulary class for more details about how to use it.
-        NOTE: token index 0 is often used as a padding index during training
+        NOTE: token index 0 is used as a padding index for training.
 
         :param sos_eos_tokens: DEPRECIATED, will include Start Of Sequence (SOS) and End Of Sequence (tokens)
         :return: the vocabulary object
@@ -242,7 +242,7 @@ class MIDILike(MIDITokenizer):
         return vocab
 
     def _create_token_types_graph(self) -> Dict[str, List[str]]:
-        """ Returns a graph (as a dictionary) of the possible token
+        r"""Returns a graph (as a dictionary) of the possible token
         types successions.
         NOTE: Program type is not referenced here, you can add it manually by
         modifying the tokens_types_graph class attribute following your strategy.
@@ -273,11 +273,11 @@ class MIDILike(MIDITokenizer):
                 dic['Rest'] += ['Chord']
             dic['Note-Off'] += ['Rest']
 
-        self._add_pad_type_to_graph(dic)
+        self._add_special_tokens_to_types_graph(dic)
         return dic
 
     def token_types_errors(self, tokens: List[int], consider_pad: bool = False) -> float:
-        """ Checks if a sequence of tokens is constituted of good token types
+        r"""Checks if a sequence of tokens is constituted of good token types
         successions and returns the error ratio (lower is better).
         The Pitch and Position values are also analyzed:
             - a Note-On token should not be present if the same pitch is already being played
@@ -330,7 +330,7 @@ class MIDILike(MIDITokenizer):
 
     @staticmethod
     def _order(x: Event) -> int:
-        """ Helper function to sort events in the right order
+        r"""Helper function to sort events in the right order
 
         :param x: event to get order index
         :return: an order int
