@@ -1,4 +1,4 @@
-""" Modified version of Octuple with no Program (Track) tokens
+"""Modified version of Octuple with no Program (Track) tokens
 To use mainly for tasks handling a single track.
 
 """
@@ -17,7 +17,7 @@ from .constants import *
 
 
 class OctupleMono(MIDITokenizer):
-    """ Modified version of Octuple with no Program (Track) tokens
+    r"""Modified version of Octuple with no Program (Track) tokens
     To use mainly for tasks handling a single track.
 
     :param pitch_range: range of used MIDI pitches
@@ -43,7 +43,7 @@ class OctupleMono(MIDITokenizer):
         super().__init__(pitch_range, beat_res, nb_velocities, additional_tokens, sos_eos_tokens, mask, params)
 
     def save_params(self, out_dir: Union[str, Path, PurePath]):
-        """ Override the parent class method to include additional parameter drum pitch range
+        r"""Override the parent class method to include additional parameter drum pitch range
         Saves the base parameters of this encoding in a txt file
         Useful to keep track of how a dataset has been tokenized / encoded
         It will also save the name of the class used, i.e. the encoding strategy
@@ -61,7 +61,7 @@ class OctupleMono(MIDITokenizer):
                       outfile)
 
     def track_to_tokens(self, track: Instrument) -> List[List[int]]:
-        """ Converts a track (miditoolkit.Instrument object) into a sequence of tokens
+        r"""Converts a track (miditoolkit.Instrument object) into a sequence of tokens
         A time step is a list of tokens where:
             (list index: token type)
             0: Pitch
@@ -129,7 +129,7 @@ class OctupleMono(MIDITokenizer):
 
     def tokens_to_track(self, tokens: List[List[int]], time_division: Optional[int] = TIME_DIVISION,
                         program: Optional[Tuple[int, bool]] = (0, False)) -> Tuple[Instrument, List[TempoChange]]:
-        """ Converts a sequence of tokens into a track object
+        r"""Converts a sequence of tokens into a track object
         A time step is a list of tokens where:
             (list index: token type)
             0: Pitch
@@ -185,7 +185,7 @@ class OctupleMono(MIDITokenizer):
         return instrument, tempo_changes
 
     def _create_vocabulary(self, sos_eos_tokens: bool = None) -> List[Vocabulary]:
-        """ Creates the Vocabulary object of the tokenizer.
+        r"""Creates the Vocabulary object of the tokenizer.
         See the docstring of the Vocabulary class for more details about how to use it.
         NOTE: token index 0 is often used as a padding index during training
 
@@ -221,7 +221,7 @@ class OctupleMono(MIDITokenizer):
         return vocab
 
     def _create_token_types_graph(self) -> Dict[str, List[str]]:
-        """ Returns a graph (as a dictionary) of the possible token
+        r"""Returns a graph (as a dictionary) of the possible token
         types successions.
         Not relevant for Octuple.
 
@@ -230,7 +230,7 @@ class OctupleMono(MIDITokenizer):
         return {}  # not relevant for this encoding
 
     def token_types_errors(self, tokens: List[List[int]]) -> float:
-        """ Checks if a sequence of tokens is constituted of good token values and
+        r"""Checks if a sequence of tokens is constituted of good token values and
         returns the error ratio (lower is better).
         The token types are always the same in Octuple so this methods only checks
         if their values are correct:
